API and Module
==================

.. currentmodule:: ml4co_kit

.. toctree::
   :maxdepth: 1

   ml4co_kit.algorithm
   ml4co_kit.data
   ml4co_kit.draw
   ml4co_kit.generator
   ml4co_kit.learning
   ml4co_kit.solver
   ml4co_kit.utils